/* Reset styles */
body {
    color: #000;
    background:#FFF;
}
body,
h1, h2, h3, h4, h5, h6,
div, p, blockquote, code, pre, th, td,
ol, ul, li, dl, dt, dd,
form, fieldset, legend, input, textarea {
    margin: 0;
    padding: 0;
}
table {
    border-collapse: collapse;
    border-spacing: 0;
}
fieldset, img {
    border:0;
}
strong, em, code, th, td {
    font-style: normal;
    font-weight: normal;
}
li {
    list-style: none;
}
h1, h2, h3, h4, h5, h6 {
    font-size: 100%;
    font-weight: normal;
}

div#replies ul li {
  padding-left: 1em;
}

/* Layout style */
.content {
    width: 750px;
    overflow: hidden;
    margin-left: auto;
    margin-right: auto;
}
.float_container {
    overflow: hidden;
}
.main_column {
    width: 425px;
}
.support_column {
    width: 300px;
}
.column {
    width: 365px;
}

/* Miscellaneous useful styles */
.hide  { display: none !important }
.left  { display: inline; float: left }
.right { display: inline; float: right }
.clear { clear: both }

/* cursor styles */
.clickable   { cursor: pointer; cursor: hand; }
.unclickable { cursor: default !important; }
.movable     { cursor: move; }
