package Grimlock::Web::View::JSON;
{
  $Grimlock::Web::View::JSON::VERSION = '0.05';
}

use strict;
use base 'Catalyst::View::JSON';

=head1 NAME

Grimlock::Web::View::JSON - Catalyst JSON View

=head1 SYNOPSIS

See L<Grimlock::Web>

=head1 DESCRIPTION

Catalyst JSON View.

=head1 AUTHOR

Devin Austin

=head1 LICENSE

This library is free software, you can redistribute it and/or modify
it under the same terms as Perl itself.

=cut

1;
